function varargout = Electrostatic_Analysis(varargin)
% ELECTROSTATIC_ANALYSIS M-file for Electrostatic_Analysis.fig
%      ELECTROSTATIC_ANALYSIS, by itself, creates a new ELECTROSTATIC_ANALYSIS or raises the existing
%      singleton*.
%
%      H = ELECTROSTATIC_ANALYSIS returns the handle to a new ELECTROSTATIC_ANALYSIS or the handle to
%      the existing singleton*.
%
%      ELECTROSTATIC_ANALYSIS('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in ELECTROSTATIC_ANALYSIS.M with the given input arguments.
%
%      ELECTROSTATIC_ANALYSIS('Property','Value',...) creates a new ELECTROSTATIC_ANALYSIS or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Electrostatic_Analysis_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Electrostatic_Analysis_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help Electrostatic_Analysis

% Last Modified by GUIDE v2.5 25-Jun-2009 10:44:18

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Electrostatic_Analysis_OpeningFcn, ...
                   'gui_OutputFcn',  @Electrostatic_Analysis_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Electrostatic_Analysis is made visible.
function Electrostatic_Analysis_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
global count mx my ID BC incount globcount credit
global analyse_press field_press force_press pot_press cap_press volt_press

axes(handles.logo)
imshow('CoNElogo.jpg')
axes(handles.grid)
count=0;
incount=0;
globcount=0;
mx=80;
my=80;
credit=0;
ID=zeros(mx,my);
BC=zeros(mx,my);
axes(handles.grid)
axis square
gridplot()

analyse_press=0;
field_press=0;
force_press=0;
pot_press=0;
cap_press=0;
volt_press=0;
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Electrostatic_Analysis (see VARARGIN)

% Choose default command line output for Electrostatic_Analysis
handles.output = hObject;
a = findall(gcf);
        hText = findall(a,'type','text');
        hUIControls = findall(a,'type','uicontrol');
        hUIPanel= findall(a,'type','uipanel');
        ax = findall(a,'type','axes');
        
set([hText; hUIControls; hUIPanel; ax],'unit','normalized');
        
% Update handles structure
guidata(hObject, handles);



% UIWAIT makes Electrostatic_Analysis wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Electrostatic_Analysis_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


function cap_Callback(hObject, eventdata, handles)
% hObject    handle to cap (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of cap as text
%        str2double(get(hObject,'String')) returns contents of cap as a double


% --- Executes during object creation, after setting all properties.
function cap_CreateFcn(hObject, eventdata, handles)
% hObject    handle to cap (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

